@@ -1,5 +1,5 @@
 #!/bin/env python3
-from link import link
+from .link import link
 import argparse
 
 def main():
@@ -13,7 +13,3 @@ def main():
 
     args = parser.parse_args()
     args.func(args)
-
-
-if __name__ == "__main__":
-    main()
